import { agent } from '@grafana/agent-core';
// adds grafana agent session id to every span
export class GrafanaAgentSessionSpanProcessor {
    constructor(processor) {
        this.processor = processor;
    }
    forceFlush() {
        return this.processor.forceFlush();
    }
    onStart(span, parentContext) {
        const session = agent.metas.value.session;
        if (session === null || session === void 0 ? void 0 : session.id) {
            span.attributes['session_id'] = session.id;
        }
        this.processor.onStart(span, parentContext);
    }
    onEnd(span) {
        this.processor.onEnd(span);
    }
    shutdown() {
        return this.processor.shutdown();
    }
}
//# sourceMappingURL=sessionSpanProcessor.js.map